<?php

namespace Drupal\contact_emails;

/**
 * Class ContactEmailSettingsForm.
 *
 * @package Drupal\contact_emails\Form
 */
class ContactEmails {

  /**
   * Get emails by contact form id.
   *
   * @param string $contact_form
   *   The contact form machine name.
   * @param bool $include_disabled
   *   Whether to include disabled contact message emails or not.
   *
   * @return array
   *   The rows from the contact message settings.
   */
  public static function getEmailsByContactForm($contact_form, $include_disabled = FALSE) {
    $query = \Drupal::database()->select('contact_message_email_settings', 'cm');
    $query->fields('cm');
    $query->condition('cm.contact_form', $contact_form);
    if (!$include_disabled) {
      $query->condition('cm.disabled', 0, '=');
    }
    $results = $query->execute()->fetchAllAssoc('id');
    return self::prepareResults($results);
  }

  /**
   * Get an email by id.
   *
   * @param int $id
   *   The email id.
   *
   * @return array
   *   The single email row from the contact message settings.
   */
  public static function getEmailById($id) {
    $query = \Drupal::database()->select('contact_message_email_settings', 'cm');
    $query->fields('cm');
    $query->condition('cm.id', $id);
    $results = $query->execute()->fetchAssoc();
    return self::prepareResult($results);
  }

  /**
   * Prepare the results in a more useable format.
   */
  protected static function prepareResults($results) {
    if (is_array($results)) {
      foreach ($results as $key => $result) {
        $results[$key] = self::prepareResult($result);
      }
    }
    return $results;
  }

  /**
   * Prepare a single result.
   */
  protected static function prepareResult($result) {
    if (isset($result->recipients) && $result->recipients) {

      // Remove new lines and carriage returns.
      $result->recipients = preg_replace("/\r|\n/", ",", $result->recipients);

      // Replace semicolons in case instructions are ignored.
      $result->recipients = str_replace(';', ',', $result->recipients);

      // Break apart into array.
      $result->recipients = explode(',', $result->recipients);

      // Trim whitespace.
      $result->recipients = array_map('trim', $result->recipients);

      // Remove empty in case double commas.
      array_filter($result->recipients);

    }
    return $result;
  }

}
